
## CATO-CLI - query.site.bgpPeer:
[Click here](https://api.catonetworks.com/documentation/#query-bgpPeer) for documentation on this operation.

### Usage for query.site.bgpPeer:

`catocli query site bgpPeer -h`

`catocli query site bgpPeer <json>`

`catocli query site bgpPeer "$(cat < bgpPeer.json)"`

`catocli query site bgpPeer '{"bgpPeerRefInput": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}'`

#### Operation Arguments for query.site.bgpPeer ####
`accountId` [ID] - (required) N/A 
`bgpPeerRefInput` [BgpPeerRefInput] - (required) N/A 
